function pattern = dirAntPattern(varargin)
%   PAT=dirAntPattern(AZ) returns the azimuth field pattern
%   at angles given in AZ (degrees). 
%   the definition for this passern is found in 3GPP TR25.996 section 4.5.1
%   PAT is a 3D-array with dimensions [2 1 LENGTH(AZ)]. 
%   The first two dimensions are the V and H 
%   polarizations, respectively.
%
%   PAT=dirAntPattern(AZ,SLANT) gives the pattern of a 
%   crosspolarized antenna. The slant angle is defined as
%   the counter clock-wise angle (in degrees) seen 
%   from the front of the dipole. 
%
%   Currently elevation is not supported. 
%
%   Example: To create a 2-element BS array with 
%   45 degrees slanted dipoles:
%       g=zeros(2,2,1,100); antpar=antparset;
%       az=linspace(-180,180);
%       g(1,:,:,:)=dirAntPattern(az,45);
%       g(2,:,:,:)=dirAntPattern(az,-45);
%       antpar.BsGainPattern=g;
%       antpar.BsGainAnglesAz=az;
% 
%definition of variable
az=varargin{1};

if (nargin==2)
    slant=varargin{2};
    slant=-slant/180*pi;    % change sign
    az_3dB = 70;           % 3dB bandwith of antenna
elseif (nargin == 3)    
    slant=varargin{2};
    slant=-slant/180*pi;    % change sign
    az_3dB = cell2mat(varargin(3));
else
    slant=0;
    az_3dB = 70;
end
Am = 30;               % maximum attenuation in dB: 20, 30
Gain = 0;              % antenna gain in dBi: 14
linGain = 10^(Gain/10);

A = -min(12*(az/az_3dB).^2, Am);
Alin = 10.^(A/20);

patternV =sqrt(linGain)*Alin*cos(slant);
patternH =sqrt(linGain)*Alin*sin(slant);

pattern = patternV.^2 + patternH.^2;

pattern = 10.*log10(pattern);
% pattern=zeros(2,1,length(az));
% pattern(1,1,:)=patternV;
% pattern(2,1,:)=patternH;